@@ -1,13 +1,13 @@
 
 package Importer::Zim::Lexical;
-$Importer::Zim::Lexical::VERSION = '0.5.0';
+$Importer::Zim::Lexical::VERSION = '0.6.0';
 # ABSTRACT: Import functions with lexical scope
 
 use 5.018;
 
 BEGIN {
     require Importer::Zim::Base;
-    Importer::Zim::Base->VERSION('0.4.0');
+    Importer::Zim::Base->VERSION('0.5.0');
     our @ISA = qw(Importer::Zim::Base);
 }
 
@@ -37,6 +37,8 @@ sub import {
 #pod
 #pod     use Importer::Zim::Lexical 'Foo' => { -version => '3.0' } => 'foo';
 #pod
+#pod     use zim 'Krazy::Taco' => qw(tacos burritos poop);
+#pod
 #pod =head1 DESCRIPTION
 #pod
 #pod    "It's... INCREDIBLE! There's stuff down here I've never even
@@ -71,7 +73,7 @@ Importer::Zim::Lexical - Import functions with lexical scope
 
 =head1 VERSION
 
-version 0.5.0
+version 0.6.0
 
 =head1 SYNOPSIS
 
@@ -83,6 +85,8 @@ version 0.5.0
 
     use Importer::Zim::Lexical 'Foo' => { -version => '3.0' } => 'foo';
 
+    use zim 'Krazy::Taco' => qw(tacos burritos poop);
+
 =head1 DESCRIPTION
 
    "It's... INCREDIBLE! There's stuff down here I've never even
